@@ -28,7 +28,7 @@ class MultiAgentDomainsConverter:
         self.logger.debug("Adding the dummy actions to the domain.")
         add_action = Action()
         add_action.name = "dummy-add-predicate-action"
-        add_action.signature = {}
+        add_action.signature = {"?agent": domain.types["object"]}
         add_action.add_effects = {DUMMY_PREDICATE}
         domain.actions[add_action.name] = add_action
 
